# remirepo spec file for php-lz4
#
# Copyright (c) 2016-2021 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%global sub_prefix %{scl_prefix}
%scl_package        php-lz4
%else
%global pkg_name    %{name}
%endif

# To build with PHP 5.x use --without apcu
%bcond_without apcu

%if 0%{?fedora} >= 34 || 0%{?rhel} >= 9
%bcond_without liblz4
%else
%bcond_with    liblz4
%endif

%global gh_commit   554722c1068a7db15f87a49ab14abae33d4db83d
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    kjdev
%global gh_project  php-ext-lz4
#global gh_date     20160608
%global pecl_name   lz4
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name    40-%{pecl_name}.ini

Summary:       LZ4 Extension for PHP
Name:          %{?sub_prefix}php-lz4
Version:       0.4.3
%if 0%{?gh_date:1}
Release:       1%{gh_date}git%{gh_short}%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
%else
Release:       1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
%endif
License:       MIT
Group:         Development/Languages
URL:           https://github.com/%{gh_owner}/%{gh_project}
Source0:       %{pkg_name}-%{version}-%{gh_short}.tgz
# retrieve a recursive git snapshot with submodule
Source1:       makesrc.sh

BuildRequires: %{?dtsprefix}gcc
%if %{with apcu}
BuildRequires: %{?scl_prefix}php-devel > 7
BuildRequires: %{?scl_prefix}php-pecl-apcu-devel
%else
BuildRequires: %{?scl_prefix}php-devel
%endif
%if %{with liblz4}
BuildRequires: lz4-devel >= 1.9
%else
Provides:      bundled(lz4) = 1.9.3
%endif

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

%if "%{?packager}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
%if "%{php_version}" > "7.3"
Obsoletes:      php73-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:      php74-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "8.0"
Obsoletes:      php80-%{pecl_name} <= %{version}
%endif
%endif


%description
This extension allows LZ4, a compression/decompression library.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc
mv %{gh_project}-%{gh_commit} NTS

cd NTS
%if %{with liblz4}
# Use the system library
rm -r lz4
%endif

# Sanity check, really often broken
extver=$(sed -n '/#define LZ4_EXT_VERSION/{s/.* "//;s/".*$//;p}' php_lz4.h)
if test "x${extver}" != "x%{version}%{?gh_date:-dev}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?gh_date:-dev}.
   exit 1
fi
cd ..

%if %{with_zts}
# duplicate for ZTS build
cp -pr NTS ZTS
%endif

# Drop in the bit of configuration
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension = %{pecl_name}.so
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --with-php-config=%{_bindir}/php-config \
%if %{with liblz4}
    --with-lz4-includedir=/usr \
%endif
    --with-libdir=%{_lib} \
    --enable-lz4
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --with-php-config=%{_bindir}/zts-php-config \
%if %{with liblz4}
    --with-lz4-includedir=/usr \
%endif
    --with-libdir=%{_lib} \
    --enable-lz4
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

# Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

%if %{with_zts}
# Install the ZTS stuff
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif



%check
cd NTS
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if "%{php_version}" > "7.0"
: Check that apcu is aware of lz4 serializer
%{__php} --no-php-ini \
    --define extension=apcu.so \
    --define apc.enabled=1 \
    --define apc.enable_cli=1 \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --ri apcu | grep '%{pecl_name}'
%endif

: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php --show-diff || : ignore

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

: Upstream test suite  for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php --show-diff
%endif


%files
%{!?_licensedir:%global license %%doc}
%license NTS/LICENSE
%doc NTS/CREDITS
%doc NTS/README.md

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Mon Jan 25 2021 Remi Collet <remi@remirepo.net> - 0.4.3-1
- update to 0.4.3

* Fri Jan 15 2021 Remi Collet <remi@remirepo.net> - 0.4.2-1
- update to 0.4.2

* Fri Dec 18 2020 Remi Collet <remi@remirepo.net> - 0.4.1-1
- update to 0.4.1 with bundled liblz4 version 1.9.3

* Fri Oct  9 2020 Remi Collet <remi@remirepo.net> - 0.4.0-1
- update to 0.4.0
- enable apcu serializer with PHP 7+

* Fri Oct  2 2020 Remi Collet <remi@remirepo.net> - 0.3.7-1
- update to 0.3.7
- drop patch merged upstream

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 0.3.6-4
- rebuild for PHP 8.0.0RC1

* Tue Sep 22 2020 Remi Collet <remi@remirepo.net> - 0.3.6-3
- add patches for PHP 8 from upstream and from
  https://github.com/kjdev/php-ext-lz4/pull/26

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.3.6-2
- rebuild for 7.4.0RC1

* Tue Aug 27 2019 Remi Collet <remi@remirepo.net> - 0.3.6-1
- update to 0.3.6 with bundled liblz4 version 1.9.2

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.3.4-3
- rebuild for 7.3.0beta2 new ABI

* Tue Jul 17 2018 Remi Collet <remi@remirepo.net> - 0.3.4-2
- rebuld for 7.3.0alpha4 new ABI

* Mon Apr  9 2018 Remi Collet <remi@remirepo.net> - 0.3.4-1
- update to 0.3.4 with bundled liblz4 version 1.8.1.2

* Mon Aug 21 2017 Remi Collet <remi@remirepo.net> - 0.3.3-1
- update to 0.3.3 with bundled liblz4 version 1.8.0

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 0.3.2-2
- rebuild for PHP 7.2.0beta1 new API

* Fri Jan  6 2017 Remi Collet <remi@fedoraproject.org> - 0.3.2-1
- update to 0.3.2

* Thu Jan  5 2017 Remi Collet <remi@fedoraproject.org> - 0.3.1-2
- test build for https://github.com/kjdev/php-ext-lz4/pull/18

* Thu Jan  5 2017 Remi Collet <remi@fedoraproject.org> - 0.3.1-1
- update to 0.3.1

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 0.3.0-2
- rebuild with PHP 7.1.0 GA

* Thu Nov 17 2016 Remi Collet <remi@fedoraproject.org> - 0.3.0-1
- update to 0.3.0

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 0.2.7-2
- rebuild for PHP 7.1 new API version

* Thu Sep  8 2016 Remi Collet <remi@fedoraproject.org> - 0.2.7-1
- update to 0.2.7 (no change)
- open https://github.com/kjdev/php-ext-lz4/pull/13

* Wed Sep  7 2016 Remi Collet <remi@fedoraproject.org> - 0.2.5-1
- new package, version 0.2.5
- open https://github.com/kjdev/php-ext-lz4/pull/11
- open https://github.com/kjdev/php-ext-lz4/pull/12

